# eric7.EricNetwork.EricGoogleMailHelpers

Module implementing some helpers for Google mail.

### Global Attributes

APPLICATION_NAME
CLIENT_SECRET_FILE
RequiredPackages
SCOPES
TOKEN_FILE

### Classes

None

### Functions

installGoogleAPIPackages | Module function to install the required packages to support Google mail.
isClientSecretFileAvailable | Module function to check, if the client secret file has been installed.

## installGoogleAPIPackages

installGoogleAPIPackages()

Module function to install the required packages to support Google mail.

Up

## isClientSecretFileAvailable

isClientSecretFileAvailable()

Module function to check, if the client secret file has been installed.

Return:
  flag indicating, that the credentials file is there

Return Type:
  bool

Up